
#include	<gobject/gmarshal.h>

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */

/* BOOLEAN:BOXED (gtkmarshal.list:24) */
extern void gtk_marshal_BOOLEAN__BOXED (GClosure     *closure,
                                        GValue       *return_value,
                                        guint         n_param_values,
                                        const GValue *param_values,
                                        gpointer      invocation_hint,
                                        gpointer      marshal_data);

/* BOOLEAN:BOXED,BOXED (gtkmarshal.list:25) */
extern void gtk_marshal_BOOLEAN__BOXED_BOXED (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
                                              const GValue *param_values,
                                              gpointer      invocation_hint,
                                              gpointer      marshal_data);

/* BOOLEAN:OBJECT,INT,INT,UINT (gtkmarshal.list:26) */
extern void gtk_marshal_BOOLEAN__OBJECT_INT_INT_UINT (GClosure     *closure,
                                                      GValue       *return_value,
                                                      guint         n_param_values,
                                                      const GValue *param_values,
                                                      gpointer      invocation_hint,
                                                      gpointer      marshal_data);

/* BOOLEAN:OBJECT,STRING,STRING,BOXED (gtkmarshal.list:27) */
extern void gtk_marshal_BOOLEAN__OBJECT_STRING_STRING_BOXED (GClosure     *closure,
                                                             GValue       *return_value,
                                                             guint         n_param_values,
                                                             const GValue *param_values,
                                                             gpointer      invocation_hint,
                                                             gpointer      marshal_data);

/* BOOLEAN:OBJECT,BOXED,BOXED (gtkmarshal.list:28) */
extern void gtk_marshal_BOOLEAN__OBJECT_BOXED_BOXED (GClosure     *closure,
                                                     GValue       *return_value,
                                                     guint         n_param_values,
                                                     const GValue *param_values,
                                                     gpointer      invocation_hint,
                                                     gpointer      marshal_data);

/* BOOLEAN:VOID (gtkmarshal.list:29) */
extern void gtk_marshal_BOOLEAN__VOID (GClosure     *closure,
                                       GValue       *return_value,
                                       guint         n_param_values,
                                       const GValue *param_values,
                                       gpointer      invocation_hint,
                                       gpointer      marshal_data);

/* BOOLEAN:BOOLEAN (gtkmarshal.list:30) */
extern void gtk_marshal_BOOLEAN__BOOLEAN (GClosure     *closure,
                                          GValue       *return_value,
                                          guint         n_param_values,
                                          const GValue *param_values,
                                          gpointer      invocation_hint,
                                          gpointer      marshal_data);

/* ENUM:ENUM (gtkmarshal.list:31) */
extern void gtk_marshal_ENUM__ENUM (GClosure     *closure,
                                    GValue       *return_value,
                                    guint         n_param_values,
                                    const GValue *param_values,
                                    gpointer      invocation_hint,
                                    gpointer      marshal_data);

/* INT:POINTER (gtkmarshal.list:32) */
extern void gtk_marshal_INT__POINTER (GClosure     *closure,
                                      GValue       *return_value,
                                      guint         n_param_values,
                                      const GValue *param_values,
                                      gpointer      invocation_hint,
                                      gpointer      marshal_data);

/* NONE:BOOL (gtkmarshal.list:33) */
#define gtk_marshal_VOID__BOOLEAN	g_cclosure_marshal_VOID__BOOLEAN
#define gtk_marshal_NONE__BOOL	gtk_marshal_VOID__BOOLEAN

/* NONE:INT (gtkmarshal.list:34) */
#define gtk_marshal_VOID__INT	g_cclosure_marshal_VOID__INT
#define gtk_marshal_NONE__INT	gtk_marshal_VOID__INT

/* NONE:INT,INT (gtkmarshal.list:35) */
extern void gtk_marshal_VOID__INT_INT (GClosure     *closure,
                                       GValue       *return_value,
                                       guint         n_param_values,
                                       const GValue *param_values,
                                       gpointer      invocation_hint,
                                       gpointer      marshal_data);
#define gtk_marshal_NONE__INT_INT	gtk_marshal_VOID__INT_INT

/* NONE:NONE (gtkmarshal.list:36) */
#define gtk_marshal_VOID__VOID	g_cclosure_marshal_VOID__VOID
#define gtk_marshal_NONE__NONE	gtk_marshal_VOID__VOID

/* NONE:POINTER (gtkmarshal.list:37) */
#define gtk_marshal_VOID__POINTER	g_cclosure_marshal_VOID__POINTER
#define gtk_marshal_NONE__POINTER	gtk_marshal_VOID__POINTER

/* NONE:STRING,INT,POINTER (gtkmarshal.list:38) */
extern void gtk_marshal_VOID__STRING_INT_POINTER (GClosure     *closure,
                                                  GValue       *return_value,
                                                  guint         n_param_values,
                                                  const GValue *param_values,
                                                  gpointer      invocation_hint,
                                                  gpointer      marshal_data);
#define gtk_marshal_NONE__STRING_INT_POINTER	gtk_marshal_VOID__STRING_INT_POINTER

/* VOID:BOOLEAN (gtkmarshal.list:39) */

/* VOID:BOXED (gtkmarshal.list:40) */
#define gtk_marshal_VOID__BOXED	g_cclosure_marshal_VOID__BOXED

/* VOID:BOXED,BOXED (gtkmarshal.list:41) */
extern void gtk_marshal_VOID__BOXED_BOXED (GClosure     *closure,
                                           GValue       *return_value,
                                           guint         n_param_values,
                                           const GValue *param_values,
                                           gpointer      invocation_hint,
                                           gpointer      marshal_data);

/* VOID:BOXED,BOXED,BOXED,BOXED (gtkmarshal.list:42) */
extern void gtk_marshal_VOID__BOXED_BOXED_BOXED_BOXED (GClosure     *closure,
                                                       GValue       *return_value,
                                                       guint         n_param_values,
                                                       const GValue *param_values,
                                                       gpointer      invocation_hint,
                                                       gpointer      marshal_data);

/* VOID:BOXED,BOXED,POINTER (gtkmarshal.list:43) */
extern void gtk_marshal_VOID__BOXED_BOXED_POINTER (GClosure     *closure,
                                                   GValue       *return_value,
                                                   guint         n_param_values,
                                                   const GValue *param_values,
                                                   gpointer      invocation_hint,
                                                   gpointer      marshal_data);

/* VOID:BOXED,POINTER (gtkmarshal.list:44) */
extern void gtk_marshal_VOID__BOXED_POINTER (GClosure     *closure,
                                             GValue       *return_value,
                                             guint         n_param_values,
                                             const GValue *param_values,
                                             gpointer      invocation_hint,
                                             gpointer      marshal_data);

/* VOID:BOXED,OBJECT (gtkmarshal.list:45) */
extern void gtk_marshal_VOID__BOXED_OBJECT (GClosure     *closure,
                                            GValue       *return_value,
                                            guint         n_param_values,
                                            const GValue *param_values,
                                            gpointer      invocation_hint,
                                            gpointer      marshal_data);

/* VOID:BOXED,STRING,INT (gtkmarshal.list:46) */
extern void gtk_marshal_VOID__BOXED_STRING_INT (GClosure     *closure,
                                                GValue       *return_value,
                                                guint         n_param_values,
                                                const GValue *param_values,
                                                gpointer      invocation_hint,
                                                gpointer      marshal_data);

/* VOID:BOXED,UINT (gtkmarshal.list:47) */
extern void gtk_marshal_VOID__BOXED_UINT (GClosure     *closure,
                                          GValue       *return_value,
                                          guint         n_param_values,
                                          const GValue *param_values,
                                          gpointer      invocation_hint,
                                          gpointer      marshal_data);

/* VOID:BOXED,UINT,FLAGS (gtkmarshal.list:48) */
extern void gtk_marshal_VOID__BOXED_UINT_FLAGS (GClosure     *closure,
                                                GValue       *return_value,
                                                guint         n_param_values,
                                                const GValue *param_values,
                                                gpointer      invocation_hint,
                                                gpointer      marshal_data);

/* VOID:BOXED,UINT,UINT (gtkmarshal.list:49) */
extern void gtk_marshal_VOID__BOXED_UINT_UINT (GClosure     *closure,
                                               GValue       *return_value,
                                               guint         n_param_values,
                                               const GValue *param_values,
                                               gpointer      invocation_hint,
                                               gpointer      marshal_data);

/* VOID:ENUM (gtkmarshal.list:50) */
#define gtk_marshal_VOID__ENUM	g_cclosure_marshal_VOID__ENUM

/* VOID:ENUM,ENUM (gtkmarshal.list:51) */
extern void gtk_marshal_VOID__ENUM_ENUM (GClosure     *closure,
                                         GValue       *return_value,
                                         guint         n_param_values,
                                         const GValue *param_values,
                                         gpointer      invocation_hint,
                                         gpointer      marshal_data);

/* VOID:ENUM,FLOAT (gtkmarshal.list:52) */
extern void gtk_marshal_VOID__ENUM_FLOAT (GClosure     *closure,
                                          GValue       *return_value,
                                          guint         n_param_values,
                                          const GValue *param_values,
                                          gpointer      invocation_hint,
                                          gpointer      marshal_data);

/* VOID:ENUM,FLOAT,BOOL (gtkmarshal.list:53) */
extern void gtk_marshal_VOID__ENUM_FLOAT_BOOLEAN (GClosure     *closure,
                                                  GValue       *return_value,
                                                  guint         n_param_values,
                                                  const GValue *param_values,
                                                  gpointer      invocation_hint,
                                                  gpointer      marshal_data);
#define gtk_marshal_VOID__ENUM_FLOAT_BOOL	gtk_marshal_VOID__ENUM_FLOAT_BOOLEAN

/* VOID:ENUM,INT (gtkmarshal.list:54) */
extern void gtk_marshal_VOID__ENUM_INT (GClosure     *closure,
                                        GValue       *return_value,
                                        guint         n_param_values,
                                        const GValue *param_values,
                                        gpointer      invocation_hint,
                                        gpointer      marshal_data);

/* VOID:ENUM,INT,BOOLEAN (gtkmarshal.list:55) */
extern void gtk_marshal_VOID__ENUM_INT_BOOLEAN (GClosure     *closure,
                                                GValue       *return_value,
                                                guint         n_param_values,
                                                const GValue *param_values,
                                                gpointer      invocation_hint,
                                                gpointer      marshal_data);

/* VOID:INT (gtkmarshal.list:56) */

/* VOID:INT,INT (gtkmarshal.list:57) */

/* VOID:INT,INT,BOXED (gtkmarshal.list:58) */
extern void gtk_marshal_VOID__INT_INT_BOXED (GClosure     *closure,
                                             GValue       *return_value,
                                             guint         n_param_values,
                                             const GValue *param_values,
                                             gpointer      invocation_hint,
                                             gpointer      marshal_data);

/* VOID:INT,INT,INT (gtkmarshal.list:59) */
extern void gtk_marshal_VOID__INT_INT_INT (GClosure     *closure,
                                           GValue       *return_value,
                                           guint         n_param_values,
                                           const GValue *param_values,
                                           gpointer      invocation_hint,
                                           gpointer      marshal_data);

/* VOID:OBJECT (gtkmarshal.list:60) */
#define gtk_marshal_VOID__OBJECT	g_cclosure_marshal_VOID__OBJECT

/* VOID:OBJECT,BOOLEAN (gtkmarshal.list:61) */
extern void gtk_marshal_VOID__OBJECT_BOOLEAN (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
                                              const GValue *param_values,
                                              gpointer      invocation_hint,
                                              gpointer      marshal_data);

/* VOID:OBJECT,BOXED,BOXED (gtkmarshal.list:62) */
extern void gtk_marshal_VOID__OBJECT_BOXED_BOXED (GClosure     *closure,
                                                  GValue       *return_value,
                                                  guint         n_param_values,
                                                  const GValue *param_values,
                                                  gpointer      invocation_hint,
                                                  gpointer      marshal_data);

/* VOID:OBJECT,BOXED,UINT,UINT (gtkmarshal.list:63) */
extern void gtk_marshal_VOID__OBJECT_BOXED_UINT_UINT (GClosure     *closure,
                                                      GValue       *return_value,
                                                      guint         n_param_values,
                                                      const GValue *param_values,
                                                      gpointer      invocation_hint,
                                                      gpointer      marshal_data);

/* VOID:OBJECT,INT,INT (gtkmarshal.list:64) */
extern void gtk_marshal_VOID__OBJECT_INT_INT (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
                                              const GValue *param_values,
                                              gpointer      invocation_hint,
                                              gpointer      marshal_data);

/* VOID:OBJECT,INT,INT,BOXED,UINT,UINT (gtkmarshal.list:65) */
extern void gtk_marshal_VOID__OBJECT_INT_INT_BOXED_UINT_UINT (GClosure     *closure,
                                                              GValue       *return_value,
                                                              guint         n_param_values,
                                                              const GValue *param_values,
                                                              gpointer      invocation_hint,
                                                              gpointer      marshal_data);

/* VOID:OBJECT,OBJECT (gtkmarshal.list:66) */
extern void gtk_marshal_VOID__OBJECT_OBJECT (GClosure     *closure,
                                             GValue       *return_value,
                                             guint         n_param_values,
                                             const GValue *param_values,
                                             gpointer      invocation_hint,
                                             gpointer      marshal_data);

/* VOID:OBJECT,STRING,STRING (gtkmarshal.list:67) */
extern void gtk_marshal_VOID__OBJECT_STRING_STRING (GClosure     *closure,
                                                    GValue       *return_value,
                                                    guint         n_param_values,
                                                    const GValue *param_values,
                                                    gpointer      invocation_hint,
                                                    gpointer      marshal_data);

/* VOID:OBJECT,UINT (gtkmarshal.list:68) */
extern void gtk_marshal_VOID__OBJECT_UINT (GClosure     *closure,
                                           GValue       *return_value,
                                           guint         n_param_values,
                                           const GValue *param_values,
                                           gpointer      invocation_hint,
                                           gpointer      marshal_data);

/* VOID:POINTER (gtkmarshal.list:69) */

/* VOID:POINTER,INT (gtkmarshal.list:70) */
extern void gtk_marshal_VOID__POINTER_INT (GClosure     *closure,
                                           GValue       *return_value,
                                           guint         n_param_values,
                                           const GValue *param_values,
                                           gpointer      invocation_hint,
                                           gpointer      marshal_data);

/* VOID:POINTER,POINTER,POINTER (gtkmarshal.list:71) */
extern void gtk_marshal_VOID__POINTER_POINTER_POINTER (GClosure     *closure,
                                                       GValue       *return_value,
                                                       guint         n_param_values,
                                                       const GValue *param_values,
                                                       gpointer      invocation_hint,
                                                       gpointer      marshal_data);

/* VOID:POINTER,UINT (gtkmarshal.list:72) */
extern void gtk_marshal_VOID__POINTER_UINT (GClosure     *closure,
                                            GValue       *return_value,
                                            guint         n_param_values,
                                            const GValue *param_values,
                                            gpointer      invocation_hint,
                                            gpointer      marshal_data);

/* VOID:STRING (gtkmarshal.list:73) */
#define gtk_marshal_VOID__STRING	g_cclosure_marshal_VOID__STRING

/* VOID:STRING,INT,POINTER (gtkmarshal.list:74) */

/* VOID:UINT,BOXED,UINT,FLAGS,FLAGS (gtkmarshal.list:75) */
extern void gtk_marshal_VOID__UINT_BOXED_UINT_FLAGS_FLAGS (GClosure     *closure,
                                                           GValue       *return_value,
                                                           guint         n_param_values,
                                                           const GValue *param_values,
                                                           gpointer      invocation_hint,
                                                           gpointer      marshal_data);

/* VOID:UINT,STRING (gtkmarshal.list:76) */
extern void gtk_marshal_VOID__UINT_STRING (GClosure     *closure,
                                           GValue       *return_value,
                                           guint         n_param_values,
                                           const GValue *param_values,
                                           gpointer      invocation_hint,
                                           gpointer      marshal_data);

/* VOID:VOID (gtkmarshal.list:77) */

#ifdef __cplusplus
}
#endif /* __cplusplus */

